@@ -27,6 +27,19 @@ def Two_Sum(num, target):
 		return
 	for i in range(0, len(int_num)):
 		for j in range(i+1, len(int_num)):
-			res = int_num[i] + int_numt[j]
+			res = int_num[i] + int_num[j]
 			if res == target:
-				print(f"[{i}, {j}],")
\ No newline at end of file
+				print(f"[{i}, {j}],")
+def Check_Palindrome(n):
+	lrev = list(str(n))
+	l = lrev.copy()
+	lrev.reverse()
+	bol = (
+		l == lrev
+		)
+	if bol == True:
+		print("The Number is Palindrome")
+		return bol
+	else:
+		print("The Number is not Palindrome")
+		return bol
\ No newline at end of file
